I2sMasterDmaChannel

Trait I2sMasterDmaChannel 

pub trait I2sMasterDmaChannel<'d, S>: Sealed + Into<AhbGdmaChannel<'d>> { }
Available on crate feature unstable only.
DMA channel trait for I2S master peripherals.

Implemented for each channel type that can serve a particular I2S instance S.

Stability

This API is marked as unstable and is only available when the unstable crate feature is enabled. This comes with no stability guarantees, and could be changed or removed at any time.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<'d> I2sMasterDmaChannel<'d, AnyI2s<'d>> for AhbGdmaChannel<'d>

Source

impl<'d> I2sMasterDmaChannel<'d, AnyI2s<'d>> for DMA_CH0<'d>

Source

impl<'d> I2sMasterDmaChannel<'d, AnyI2s<'d>> for DMA_CH1<'d>

Source

impl<'d> I2sMasterDmaChannel<'d, I2S0<'d>> for AhbGdmaChannel<'d>

Source

impl<'d> I2sMasterDmaChannel<'d, I2S0<'d>> for DMA_CH0<'d>

Source

impl<'d> I2sMasterDmaChannel<'d, I2S0<'d>> for DMA_CH1<'d>